@@ -26,18 +26,11 @@ sub new
     return $self;
 } ## end sub new
 
-sub name
-{
-    my ($self) = @_;
-
-    return $self->{function};
-} ## end sub name
-
 sub find
 {
     my ($self) = @_;
 
-    my ($ok, $markdown) = $self->run_perldoc_command('-Tuf', $self->name);
+    my ($ok, $markdown) = $self->run_perldoc_command('-Tuf', $self->{function});
 
     $self->{markdown} = $markdown if $ok;
     return $ok;
